# comment out if not nightly build
#define nightly	20180604
#define gitcommit cf92a76

# rel to bump
%define rel	1

# build will override this anyway, so let's skip it
%define _fortify_cflags %nil
%define luaver	5.3

Name:		neovim
Version:	0.4.4
Release:	%mkrel %{?nightly:0.%{nightly}.git%{gitcommit}.}%{rel}
Summary:	Vim-fork focused on extensibility and usability
Group:		Editors
License:	ASL 2.0
URL:		https://neovim.io/
%if 0%{?nightly:1}
Source0:	https://github.com/neovim/neovim/archive/nightly/%{name}-%{version}-nightly%{nightly}.tar.gz
%else
Source0:	https://github.com/neovim/neovim/archive/v%{version}/%{name}-%{version}.tar.gz
%endif
# We add an extra build option to disable this error from stopping the build
Patch0:		01-Wno-misleading-indentation.patch
Patch1:		neovim-0.2.1-bitop.patch
BuildRequires:	cmake
BuildRequires:	gperf
BuildRequires:	lua-lpeg
BuildRequires:	lua-mpack
BuildRequires:	lua-luv-devel
BuildRequires:	ninja
BuildRequires:	lua%{luaver}-devel
BuildRequires:	pkgconfig(libuv)
BuildRequires:	pkgconfig(msgpack)
BuildRequires:	pkgconfig(unibilium)
BuildRequires:	pkgconfig(termkey)
BuildRequires:	pkgconfig(vterm)
BuildRequires:	pkgconfig(jemalloc)
BuildRequires:	pkgconfig(libbsd)
Requires:	%{name}-data >= %{version}-%{release}
Requires:	lua%{luaver}
Provides:	nvim = %{version}-%{release}
Recommends:	xclip
Recommends:	python3dist(pynvim)
Recommends:	npm(neovim)

%description
Neovim is a project that seeks to aggressively refactor Vim in order to:

- Simplify maintenance and encourage contributions
- Split the work between multiple developers
- Enable advanced UIs without modifications to the core
- Maximize extensibility

%package data
Summary:	Data files for %{name}
BuildArch:	noarch

%description data
Data files for %{name}.

%prep
%autosetup -p1 -n %{name}-%{?nightly:nightly}%{?!nightly:%{version}}

sed -i "s|sys/end|bsd/sys/end|g" config/CMakeLists.txt

%build
%cmake	-Wno-dev -GNinja \
	-DPREFER_LUA=ON \
	-DUSE_BUNDLED_LUAJIT=OFF \
	-DUSE_BUNDLED=OFF \
	-DLUA_PRG=%{_bindir}/lua%{luaver} \
	-DUSE_SYSTEM_MSGPACK=ON \
	-DWITH_PLUGINS=ON \
	-DUSE_BUNDLED_LUV=OFF \
	-DUSE_SYSTEM_LUV=ON \
	-DUSE_BUNDLED_LUAROCKS=OFF
%ninja_build -C %{_vpath_builddir}

%install
%ninja_install -C %{_vpath_builddir}

%find_lang nvim

%files
%license LICENSE
%doc BACKERS.md CONTRIBUTING.md README.md
%{_bindir}/nvim
%{_mandir}/man1/nvim.1*
%{_datadir}/pixmaps/nvim.png
%{_datadir}/applications/nvim.desktop

%files data -f nvim.lang
%{_datadir}/nvim/


%changelog
* Wed Aug 05 2020 joequant <joequant> 0.4.4-1.mga8
+ Revision: 1611194
- update to 0.4.4

* Sun Apr 05 2020 wally <wally> 0.4.3-3.mga8
+ Revision: 1564921
- build with lua5.3

* Mon Feb 17 2020 umeabot <umeabot> 0.4.3-2.mga8
+ Revision: 1537679
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Nov 06 2019 kekepower <kekepower> 0.4.3-1.mga8
+ Revision: 1458476
- Update to version 0.4.3

* Wed Sep 18 2019 kekepower <kekepower> 0.4.2-1.mga8
+ Revision: 1443515
- Update to version 0.4.2

* Sat Jul 06 2019 kekepower <kekepower> 0.3.8-1.mga8
+ Revision: 1419019
- Update to version 0.3.8

* Fri Jun 07 2019 kekepower <kekepower> 0.3.7-1.mga8
+ Revision: 1399642
- Update to version 0.3.7 to fix CVE-2019-12735 (mga#24929)

* Mon Apr 29 2019 kekepower <kekepower> 0.3.5-1.mga7
+ Revision: 1395845
- Update to version 0.3.5

* Sun Jan 13 2019 kekepower <kekepower> 0.3.4-1.mga7
+ Revision: 1355953
- Update to version 0.3.4

* Sat Jan 05 2019 kekepower <kekepower> 0.3.3-1.mga7
+ Revision: 1349235
- Update to version 0.3.3

* Mon Dec 31 2018 kekepower <kekepower> 0.3.2-1.mga7
+ Revision: 1347387
- Update to version 0.3.2

* Fri Dec 14 2018 kekepower <kekepower> 0.3.1-3.mga7
+ Revision: 1341280
- Fix Requires and Recommends

* Sun Sep 23 2018 umeabot <umeabot> 0.3.1-2.mga7
+ Revision: 1299697
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 kekepower <kekepower> 0.3.1-1.mga7
+ Revision: 1248796
- Update to version 0.3.1

* Mon Jun 11 2018 kekepower <kekepower> 0.3.0-1.mga7
+ Revision: 1236296
- Update to version 0.3.0
- Recommend python-neovim and nodejs-neovim

* Fri Apr 27 2018 daviddavid <daviddavid> 0.2.2-3.mga7
+ Revision: 1222899
- rebuild against lua 5.3

* Sun Mar 11 2018 wally <wally> 0.2.2-2.mga7
+ Revision: 1208161
- rebuild for new unibilium 2.0.0

* Mon Dec 04 2017 wally <wally> 0.2.2-1.mga7
+ Revision: 1181178
- new version 0.2.2

* Thu Nov 09 2017 wally <wally> 0.2.1-1.mga7
+ Revision: 1176714
- new version 0.2.1

* Sun Oct 29 2017 wally <wally> 0.2.0-2.mga7
+ Revision: 1174860
- recommend xsel for optional clipboard support

* Sun Oct 29 2017 wally <wally> 0.2.0-1.mga7
+ Revision: 1174787
- imported package neovim

